@@ -124,6 +124,7 @@ pub fn handle_key_event_or_break(
             KeyCode::F(3) => app.toggle_search_regex(),
             KeyCode::F(5) => app.toggle_tree_mode(),
             KeyCode::F(6) => app.toggle_sort(),
+            KeyCode::F(9) => app.start_killing_process(),
             _ => {}
         }
     } else {
@@ -186,14 +187,14 @@ pub fn read_config(config_location: Option<&str>) -> error::Result<Option<PathBu
     let config_path = if let Some(conf_loc) = config_location {
         Some(PathBuf::from(conf_loc))
     } else if cfg!(target_os = "windows") {
-        if let Some(home_path) = dirs_next::config_dir() {
+        if let Some(home_path) = dirs::config_dir() {
             let mut path = home_path;
             path.push(DEFAULT_CONFIG_FILE_PATH);
             Some(path)
         } else {
             None
         }
-    } else if let Some(home_path) = dirs_next::home_dir() {
+    } else if let Some(home_path) = dirs::home_dir() {
         let mut path = home_path;
         path.push(".config/");
         path.push(DEFAULT_CONFIG_FILE_PATH);
@@ -202,7 +203,7 @@ pub fn read_config(config_location: Option<&str>) -> error::Result<Option<PathBu
             Some(path)
         } else {
             // If it does not, use the new one!
-            if let Some(config_path) = dirs_next::config_dir() {
+            if let Some(config_path) = dirs::config_dir() {
                 let mut path = config_path;
                 path.push(DEFAULT_CONFIG_FILE_PATH);
                 Some(path)
@@ -408,7 +409,7 @@ fn update_final_process_list(app: &mut App, widget_id: u64) {
                 .filter_map(|(_pid, process)| {
                     if !is_invalid_or_blank {
                         if let Some(process_filter) = process_filter {
-                            if process_filter.check(&process, is_using_command) {
+                            if process_filter.check(process, is_using_command) {
                                 Some(process)
                             } else {
                                 None
@@ -454,7 +455,7 @@ fn update_final_process_list(app: &mut App, widget_id: u64) {
 
             app.canvas_data.stringified_process_data_map.insert(
                 widget_id,
-                stringify_process_data(&proc_widget_state, &finalized_process_data),
+                stringify_process_data(proc_widget_state, &finalized_process_data),
             );
             app.canvas_data
                 .finalized_process_data_map
@@ -594,9 +595,7 @@ pub fn create_input_thread(
     >,
     termination_ctrl_lock: Arc<Mutex<bool>>,
 ) -> std::thread::JoinHandle<()> {
-    // trace!("Creating input thread.");
     thread::spawn(move || {
-        // trace!("Spawned input thread.");
         let mut mouse_timer = Instant::now();
         let mut keyboard_timer = Instant::now();
 
@@ -604,7 +603,6 @@ pub fn create_input_thread(
             if let Ok(is_terminated) = termination_ctrl_lock.try_lock() {
                 // We don't block.
                 if *is_terminated {
-                    // trace!("Received termination lock in input thread!");
                     drop(is_terminated);
                     break;
                 }
@@ -612,13 +610,11 @@ pub fn create_input_thread(
             if let Ok(poll) = poll(Duration::from_millis(20)) {
                 if poll {
                     if let Ok(event) = read() {
-                        // trace!("Input thread received an event: {:?}", event);
                         if let Event::Key(key) = event {
                             if Instant::now().duration_since(keyboard_timer).as_millis() >= 20 {
                                 if sender.send(BottomEvent::KeyInput(key)).is_err() {
                                     break;
                                 }
-                                // trace!("Input thread sent keyboard data.");
                                 keyboard_timer = Instant::now();
                             }
                         } else if let Event::Mouse(mouse) = event {
@@ -626,7 +622,6 @@ pub fn create_input_thread(
                                 if sender.send(BottomEvent::MouseInput(mouse)).is_err() {
                                     break;
                                 }
-                                // trace!("Input thread sent mouse data.");
                                 mouse_timer = Instant::now();
                             }
                         }
@@ -634,7 +629,6 @@ pub fn create_input_thread(
                 }
             }
         }
-        // trace!("Input thread loop has closed.");
     })
 }
 
@@ -647,36 +641,31 @@ pub fn create_collection_thread(
     app_config_fields: &app::AppConfigFields, filters: app::DataFilters,
     used_widget_set: UsedWidgets,
 ) -> std::thread::JoinHandle<()> {
-    // trace!("Creating collection thread.");
     let temp_type = app_config_fields.temperature_type.clone();
     let use_current_cpu_total = app_config_fields.use_current_cpu_total;
     let show_average_cpu = app_config_fields.show_average_cpu;
     let update_rate_in_milliseconds = app_config_fields.update_rate_in_milliseconds;
 
     thread::spawn(move || {
-        // trace!("Spawned collection thread.");
         let mut data_state = data_harvester::DataCollector::new(filters);
-        // trace!("Created default data state.");
+
         data_state.set_collected_data(used_widget_set);
         data_state.set_temperature_type(temp_type);
         data_state.set_use_current_cpu_total(use_current_cpu_total);
         data_state.set_show_average_cpu(show_average_cpu);
-        // trace!("Set default data state settings.");
 
         data_state.init();
-        // trace!("Data state is now fully initialized.");
+
         loop {
             // Check once at the very top...
             if let Ok(is_terminated) = termination_ctrl_lock.try_lock() {
                 // We don't block here.
                 if *is_terminated {
-                    // trace!("Received termination lock in collection thread!");
                     drop(is_terminated);
                     break;
                 }
             }
 
-            // trace!("Checking for collection control receiver event...");
             let mut update_time = update_rate_in_milliseconds;
             if let Ok(message) = control_receiver.try_recv() {
                 // trace!("Received message in collection thread: {:?}", message);
@@ -704,32 +693,26 @@ pub fn create_collection_thread(
             if let Ok(is_terminated) = termination_ctrl_lock.try_lock() {
                 // We don't block here.
                 if *is_terminated {
-                    // trace!("Received termination lock in collection thread!");
                     drop(is_terminated);
                     break;
                 }
             }
 
-            // trace!("Collection thread is updating and sending...");
             let event = BottomEvent::Update(Box::from(data_state.data));
             data_state.data = data_harvester::Data::default();
             if sender.send(event).is_err() {
-                // trace!("Error sending from collection thread...");
                 break;
             }
-            // trace!("No problem sending from collection thread!");
 
             if let Ok((is_terminated, _wait_timeout_result)) = termination_ctrl_cvar.wait_timeout(
                 termination_ctrl_lock.lock().unwrap(),
                 Duration::from_millis(update_time),
             ) {
                 if *is_terminated {
-                    // trace!("Received termination lock in collection thread from cvar!");
                     drop(is_terminated);
                     break;
                 }
             }
         }
-        // trace!("Collection thread loop has closed.");
     })
 }
